@@ -14,7 +14,7 @@ class parser;
     Store the result in \c ps.
 
     Return true when levels were provided. */
-bool parse_univ_params(parser & p, buffer<name> & ps);
+ast_id parse_univ_params(parser & p, buffer<name> & ps);
 
 /** \brief Add universe levels from \c found_ls to \c ls_buffer
     (only the levels that do not already occur in \c ls_buffer are added).
@@ -23,7 +23,7 @@ bool parse_univ_params(parser & p, buffer<name> & ps);
 void update_univ_parameters(buffer<name> & ls_buffer, name_set const & found_ls, parser const & p);
 
 /** \brief Parse a local attribute command */
-environment local_attribute_cmd(parser & p, cmd_meta const & meta);
+environment local_attribute_cmd(parser & p, ast_id & cmd_id, cmd_meta const & meta);
 void register_decl_cmds(cmd_table & r);
 
 void initialize_decl_cmds();
