@@ -9,9 +9,7 @@ Author: Leonardo de Moura
 #include "frontends/lean/decl_attributes.h"
 #include "frontends/lean/decl_util.h"
 namespace lean {
-environment definition_cmd_core(parser & p, decl_cmd_kind k, cmd_meta const & meta);
+environment definition_cmd_core(parser & p, decl_cmd_kind k, ast_id cmd_id, cmd_meta const & meta);
 
-environment single_definition_cmd_core(parser_info & p, decl_cmd_kind kind, cmd_meta meta);
-
-environment ensure_decl_namespaces(environment const & env, name const & full_n);
+environment single_definition_cmd_core(parser_info & p, decl_cmd_kind kind, ast_data * parent, cmd_meta meta);
 }
