@@ -6,6 +6,7 @@ Author: Gabriel Ebner
 */
 #ifdef LEAN_JSON
 #pragma once
+#include <string>
 #include "library/messages.h"
 #include "kernel/environment.h"
 #include "util/lean_json.h"
@@ -21,6 +22,8 @@ json json_of_name(name const &);
 json to_json(name const &);
 
 void add_source_info(environment const & env, name const & d, json & record);
+std::string get_decl_kind(name const & name, declaration const & d, environment const & env);
+expr consume_implicit_binders(expr type);
 json serialize_decl(name const & short_name, name const & long_name, environment const & env, options const & o);
 json serialize_decl(name const & d, environment const & env, options const & o);
 
