@@ -586,14 +586,6 @@ public:
         return *this;
     }
 
-    parray & operator=(parray && s) {
-        if (m_cell)
-            dec_ref(m_cell);
-        m_cell = s.m_ptr;
-        s.m_ptr = nullptr;
-        return *this;
-    }
-
     size_t size() const {
         return size(m_cell);
     }
