@@ -619,10 +619,7 @@ public:
        4- (Drawback) Local instances cannot be reverted anymore.
 
        This method is invoked after we parse the header of a declaration.
-
-       TODO(Leo):
-       add tactic `unfreeze_local_instances : tactic unit` which unfreezes the set of frozen local instances
-       for the current goal. */
+    */
     void freeze_local_instances();
     void unfreeze_local_instances();
     list<local_instance> get_local_instances() const { return m_local_instances; }
@@ -740,6 +737,8 @@ public:
 
     optional<name> is_class(expr const & type);
     optional<expr> mk_class_instance(expr const & type);
+    /* Are sufficiently many metavariables instantiated for synthesis? */
+    bool ready_to_synthesize(expr inst_type);
     optional<expr> mk_subsingleton_instance(expr const & type);
     /* Create type class instance in a different local context */
     optional<expr> mk_class_instance_at(local_context const & lctx, expr const & type);
@@ -1081,6 +1080,7 @@ public:
     bool is_eassigned(unsigned i) const;
     void clear_eassignment();
     expr instantiate_mvars(expr const & e);
+    optional<expr> mk_class_instance(expr const & cls_type);
 };
 
 /** Create a formatting function that can 'decode' metavar_decl_refs and local_decl_refs
