@@ -11,7 +11,16 @@ namespace lean {
 int to_int(vm_obj const & o);
 optional<int> try_to_int(vm_obj const & o);
 int force_to_int(vm_obj const & o, int def);
-vm_obj mk_vm_int(int i);
+
+vm_obj mk_vm_int(int n);
+vm_obj mk_vm_int(unsigned int n);
+vm_obj mk_vm_int(long n);
+vm_obj mk_vm_int(unsigned long n);
+vm_obj mk_vm_int(long long n);
+vm_obj mk_vm_int(unsigned long long n);
+vm_obj mk_vm_int(double n);
+vm_obj mk_vm_int(mpz const & n);
+
 void initialize_vm_int();
 void finalize_vm_int();
 }
