@@ -9,8 +9,8 @@ Author: Sebastian Ullrich
 #include "frontends/lean/parser.h"
 
 namespace lean {
-vm_obj run_parser(parser & p, expr const & spec, buffer<vm_obj> const & args = {}, bool allow_profiler = false);
-expr parse_interactive_param(parser & p, expr const & param_ty);
+pair<ast_id, vm_obj> run_parser(parser & p, expr const & spec, buffer<vm_obj> const & args = {}, bool allow_profiler = false);
+expr parse_interactive_param(parser & p, ast_data & parent, expr const & param_ty);
 
 vm_obj to_obj(cmd_meta const & meta);
 
